$(document).ready(function () {
  $('#signup-section').hide();
  let loginErrorOccurred = $('#loginError');
  let loginEmailError = $('#loginEmailError');
  let loginPinError = $('#loginPinErr');
  let firstNameErr = $('#firstNameErr');
  let lastNameErr = $('#lastNameErr');
  let emailErr = $('#emailErr');
  let pinErr = $('#pinErr');
  let confirmPinErr = $('#confirmPinErr');
  let errorOccured = $('#signupError');
  let base_url = 'https://crustsolutionsgh.com:8208';
  let anErrorOccurredString = 'An error occurred. Please try again.';
  Ladda.bind('button[type=submit]');

  errorOccured.hide();
  loginErrorOccurred.hide();

  // toggle signup form
  $('#create-account-btn').on('click', function (e) {
    e.preventDefault();

    $('#login-section').hide();
    $('#signup-section').show();
  });

  // toggle login form
  $('#login-btn').on('click', function (e) {
    e.preventDefault();

    $('#signup-section').hide();
    $('#login-section').show();
  });

  // signup form handling
  $('#form-signup').on('submit', function (e) {
    e.preventDefault();

    let fname = $('#first_name').val();
    let lname = $('#last_name').val();
    let email = $('#signup-email').val();
    let pin = $('#pin').val();
    let confirm_pin = $('#confirm_pin').val();

    if (validateSignupForm(fname, lname, email, pin, confirm_pin)) {
      sendSignupFormData(fname, lname, email, pin);
    } else {
      Ladda.stopAll();
    }
  });

  // login form handling
  $('#form-login').on('submit', function (e) {
    e.preventDefault();

    let loginEmail = $('#login_email').val();
    let loginPin = $('#login_pin').val();

    if (validateLoginForm(loginEmail, loginPin)) {
      sendLoginFormData(loginEmail, loginPin);
    } else {
      Ladda.stopAll();
    }
  });

  // validating values from signup form
  function validateSignupForm(fname, lname, email, pin, confirm_pin) {
    // let numbers = /^[0-9]+$/;

    firstNameErr.hide();
    lastNameErr.hide();
    emailErr.hide();
    pinErr.hide();
    confirmPinErr.hide();
    errorOccured.hide();

    if (
      fname === '' &&
      lname === '' &&
      email === '' &&
      pin === '' &&
      confirm_pin === ''
    ) {
      displayErrorOccurred('All fields are required.');
      return false;
    }

    if (fname === '') {
      firstNameErr.empty();
      firstNameErr.append('First name is required.');
      firstNameErr.show();
      return false;
    }

    if (fname.length < 2) {
      firstNameErr.empty();
      firstNameErr.append('First name should be at least 2 characters.');
      firstNameErr.show();
      return false;
    }

    if (lname === '') {
      lastNameErr.empty();
      lastNameErr.append('Last name is required.');
      lastNameErr.show();
      return false;
    }

    if (lname.length < 2) {
      lastNameErr.empty();
      lastNameErr.append('First name should be at least 2 characters.');
      lastNameErr.show();
      return false;
    }

    if (email === '') {
      emailErr.empty();
      emailErr.append('Email is required.');
      emailErr.show();
      return false;
    }

    if (email.indexOf('@', 0) < 0) {
      emailErr.empty();
      emailErr.append('Email is not valid.');
      emailErr.show();
      return false;
    }

    if (email.indexOf('.', 0) < 0) {
      emailErr.empty();
      emailErr.append('Email is not valid.');
      emailErr.show();
      return false;
    }

    if (pin === '') {
      pinErr.empty();
      pinErr.append('Pin is required.');
      pinErr.show();
      return false;
    }

    if (isNaN(pin)) {
      pinErr.empty();
      pinErr.append('Pin should be only numbers.');
      pinErr.show();
      return false;
    }

    if (pin.length !== 6) {
      pinErr.empty();
      pinErr.append('Pin should be 6 digits.');
      pinErr.show();
      return false;
    }

    if (pin !== confirm_pin) {
      confirmPinErr.empty();
      confirmPinErr.append('Pins do no match.');
      confirmPinErr.show();
      return false;
    }

    return true;
  }

  // send form data using ajax request
  function sendSignupFormData(fname, lname, email, pin) {
    let data = {
      first_name: fname,
      last_name: lname,
      email: email,
      pin: pin,
    };
    let signup_endpoint = base_url + '/newUser';

    $.ajax({
      dataType: 'JSON',
      type: 'POST',
      url: signup_endpoint,
      data: JSON.stringify(data),
      secure: true,
      success: function (data) {
        Ladda.stopAll();

        if (data.status) {
          if (data.status === '0') {
            // successful // show sweet alert
            Swal.fire(
              'Signup successful.',
              'Please login to check your subscription.',
              'success'
            );
            $('#form-signup').trigger('reset');
          } else {
            displayErrorOccurred(anErrorOccurredString);
          }
        } else {
          displayErrorOccurred(anErrorOccurredString);
        }
      },
      error: function (err) {
        Ladda.stopAll();
        displayErrorOccurred(anErrorOccurredString);
      },
    });
  }

  // validate login form
  function validateLoginForm(login_email, login_pin) {
    loginEmailError.hide();
    loginPinError.hide();
    loginErrorOccurred.hide();

    if (login_email === '') {
      loginEmailError.empty();
      loginEmailError.append('Email is required.');
      loginEmailError.show();
      return false;
    }

    if (login_email.indexOf('@', 0) < 0) {
      loginEmailError.empty();
      loginEmailError.append('Email is not valid.');
      loginEmailError.show();
      return false;
    }

    if (login_email.indexOf('.', 0) < 0) {
      loginEmailError.empty();
      loginEmailError.append('Email is not valid.');
      loginEmailError.show();
      return false;
    }

    if (login_pin === '') {
      loginPinError.empty();
      loginPinError.append('Pin is required.');
      loginPinError.show();
      return false;
    }

    return true;
  }

  // send login forom data
  function sendLoginFormData(login_email, login_pin) {
    let data = {
      email: login_email,
      pin: login_pin,
    };
    let loginUrl = base_url + '/userLogin';

    $.ajax({
      dataType: 'json',
      type: 'POST',
      url: loginUrl,
      data: JSON.stringify(data),
      secure: true,
      success: function (response) {
        Ladda.stopAll();

        logData(response);

        if (response.status) {
          if (response.status === '0') {
            sessionStorage.setItem('email', login_email);
            window.location.href = 'subscription.php';
          } else {
            displayLoginErrorOccurred('Invalid credentials.');
          }
        } else {
          displayLoginErrorOccurred(anErrorOccurredString);
        }
      },
      error: function (err) {
        Ladda.stopAll();
        displayLoginErrorOccurred(anErrorOccurredString);
      },
    });
  }

  // display error occurred alert
  function displayErrorOccurred(msg) {
    errorOccured.empty();
    errorOccured.append(msg);
    errorOccured.show();
  }

  // display error occurred alert for login
  function displayLoginErrorOccurred(msg) {
    loginErrorOccurred.empty();
    loginErrorOccurred.append(msg);
    loginErrorOccurred.show();
  }

  function logData(data) {
    // console.log(data);
  }

  // function test(username, query) {
  //
  //     let data = {
  //         username: username,
  //         query: query
  //     };
  //     let url = "http://192.168.5.3:8002/queryUser";
  //
  //     $.ajax({
  //         dataType: 'json',
  //         type:'POST',
  //         url: url,
  //         data: JSON.stringify(data),
  //         secure: true,
  //         success: function (response) {
  //             console.log(response);
  //
  //         },
  //         error: function (err) {
  //             console.log(err);
  //         }
  //     });
  //
  // }
});
